@@ -447,7 +447,7 @@ class path(pathmeta('base_path', (base_string_class, ), {})):
         """
         sort = sort or (lambda e: (not e.is_dir(), e))
         content = [
-            path(e) for e in os.listdir(self) if fnmatch.fnmatch(e, pattern)
+            self / path(e) for e in os.listdir(self) if fnmatch.fnmatch(e, pattern)
         ]
         return sorted(content, key=sort)
 
@@ -460,7 +460,7 @@ class path(pathmeta('base_path', (base_string_class, ), {})):
 
         :rtype: list
         """
-        return [e for e in self.ls(patern, sort) if (self / e).is_file()]
+        return [e for e in self.ls(patern, sort) if e.is_file()]
 
     def ls_dirs(self, patern="*", sort=None):
         """
@@ -471,7 +471,7 @@ class path(pathmeta('base_path', (base_string_class, ), {})):
 
         :rtype: list
         """
-        return [e for e in self.ls(patern, sort) if (self / e).is_dir()]
+        return [e for e in self.ls(patern, sort) if e.is_dir()]
 
     def walk(self, pattern="*", r=False, sort=None):
         """
