@@ -148,26 +148,32 @@ def test_touch():
 
 def test_ls():
     dir_content = path(root).ls()
+
+    names_only = [a.basename for a in dir_content]
+
     assert len(dir_content) == len(dir_list + file_list)
-    assert set(dir_list).issubset(dir_content)
-    assert set(file_list).issubset(dir_content)
+    assert set(dir_list).issubset(names_only)
+    assert set(file_list).issubset(names_only)
 
 
 def test_ls_files():
     dir_content = path(root).ls_files()
-    assert len(dir_content) == len(file_list)
 
-    assert not set(dir_list).issubset(dir_content)
-    assert set(file_list).issubset(dir_content)
+    names_only = [a.basename for a in dir_content]
+
+    assert len(dir_content) == len(file_list)
+    assert not set(dir_list).issubset(names_only)
+    assert set(file_list).issubset(names_only)
 
 
 def test_ls_dirs():
     dir_content = path(root).ls_dirs()
 
-    assert len(dir_content) == len(dir_list)
+    names_only = [a.basename for a in dir_content]
 
-    assert set(dir_list).issubset(dir_content)
-    assert not set(file_list).issubset(dir_content)
+    assert len(dir_content) == len(dir_list)
+    assert set(dir_list).issubset(names_only)
+    assert not set(file_list).issubset(names_only)
 
 
 def test_walk():
